@@ -31,39 +31,39 @@ NULL
 #' @examples 
 #' node_components(mpn_bristol)
 #' @export
-node_components <- function(object){
-  if(!is_graph(object)) object <- as_igraph(object)
-  make_node_member(igraph::components(object, mode = "strong")$membership,
-              object)
+node_components <- function(.data){
+  if(!manynet::is_graph(.data)) .data <- manynet::as_igraph(.data)
+  make_node_member(igraph::components(.data, mode = "strong")$membership,
+              .data)
 }
 
 #' @describeIn components Returns nodes' component membership
 #'   ignoring edge direction.
 #' @importFrom igraph components
 #' @export
-node_weak_components <- function(object){
-  if(!is_graph(object)) object <- as_igraph(object)
-  make_node_member(igraph::components(object, mode = "weak")$membership,
-                 object)
+node_weak_components <- function(.data){
+  if(!manynet::is_graph(.data)) .data <- manynet::as_igraph(.data)
+  make_node_member(igraph::components(.data, mode = "weak")$membership,
+                 .data)
 }
 
 #' @describeIn components Returns nodes' component membership
 #'   based on edge direction.
 #' @importFrom igraph components
 #' @export
-node_strong_components <- function(object){
-  if(!is_graph(object)) object <- as_igraph(object)
-  make_node_member(igraph::components(object, mode = "strong")$membership,
-                 object)
+node_strong_components <- function(.data){
+  if(!manynet::is_graph(.data)) .data <- manynet::as_igraph(.data)
+  make_node_member(igraph::components(.data, mode = "strong")$membership,
+                 .data)
 }
 
 #' @describeIn components Returns k-cores
 #' @examples
 #' node_coreness(ison_adolescents)
 #' @export
-node_coreness <- function(object){
-  if(!is_graph(object)) object <- as_igraph(object)
-  out <- igraph::coreness(object)
-  make_node_member(out, object)
+node_coreness <- function(.data){
+  if(!manynet::is_graph(.data)) .data <- manynet::as_igraph(.data)
+  out <- igraph::coreness(.data)
+  make_node_member(out, .data)
 }
 
