@@ -46,10 +46,6 @@ tidygraph::mutate
 #' @export
 tidygraph::rename
 
-#' @importFrom tidygraph filter
-#' @export
-tidygraph::filter
-
 #' @importFrom tidygraph activate
 #' @export
 tidygraph::activate
